@@ -32,7 +32,10 @@ from mitosheet.mito_widget import MitoWidget, sheet
 from mitosheet.saved_analyses import register_analysis
 from mitosheet.errors import CreationError, EditError
 from mitosheet._version import __version__
-from mitosheet.utils import make_valid_header
+from mitosheet.column_headers import flatten_column_header
+
+# We export depricated utilities, so that users can still use them if they used to
+from mitosheet.step_performers.bulk_old_rename.deprecated_utils import make_valid_header_external as make_valid_header
 
 # Export all the sheet functions
 from mitosheet.sheet_functions import *
