@@ -214,6 +214,8 @@ class MitoWidget(DOMWidget):
             # passed to this function, and thus is logged. However, we do not log
             # api calls, as they are just noise.
             log_event_processed(event, self.steps_manager)
+
+            return True
         except EditError as e:
             print(get_recent_traceback())
             print(e)
@@ -242,6 +244,8 @@ class MitoWidget(DOMWidget):
                 'to_fix': 'Sorry, there was an error during executing this code.'
             })
 
+        return False
+
 def sheet(
         *args, 
     ) -> MitoWidget:
