@@ -19,7 +19,7 @@ import pandas as pd
 import functools
 
 from mitosheet.sheet_functions.types.decorators import convert_arg_to_series_type, convert_args_to_series_type, filter_nans, fill_nans, handle_sheet_function_errors
-from mitosheet.sheet_functions.sheet_function_utils import fill_series_list_to_max, fill_series_to_length
+from mitosheet.sheet_functions.sheet_function_utils import try_extend_series_to_index, fill_series_with_one_index
 
 
 @handle_sheet_function_errors
@@ -47,7 +47,7 @@ def AND(*argv) -> pd.Series:
         ]
     }
     """
-    argv = fill_series_list_to_max(argv)
+    argv = fill_series_with_one_index(argv)
 
     return functools.reduce((lambda x, y: x & y), argv)
 
@@ -101,7 +101,7 @@ def BOOL(series) -> pd.Series:
     'error',
     'error'
 )
-def IF(condition, true_series, false_series) -> pd.Series:
+def IF(condition: pd.Series, true_series, false_series) -> pd.Series:
     """
     {
         "function": "IF",
@@ -127,11 +127,12 @@ def IF(condition, true_series, false_series) -> pd.Series:
         ]
     }
     """
-    true_series = fill_series_to_length(true_series, len(condition))
-    false_series = fill_series_to_length(false_series, len(condition))
+    true_series = try_extend_series_to_index(true_series, condition.index)
+    false_series = try_extend_series_to_index(false_series, condition.index)
 
     return pd.Series(
-        data=[true_series[i] if c else false_series[i] for i, c in enumerate(condition)]
+        data=[true_series.loc[i] if c else false_series.loc[i] for i, c in condition.iteritems()],
+        index=condition.index
     )
 
 
@@ -160,7 +161,7 @@ def OR(*argv) -> pd.Series:
     }
     """
 
-    argv = fill_series_list_to_max(argv)
+    argv = fill_series_with_one_index(argv)
     return functools.reduce((lambda x, y: x | y), argv)
 
 
