@@ -13,7 +13,7 @@ in more detail in docs/README.md.
 
 NOTE: This file is alphabetical order!
 """
-from mitosheet.sheet_functions.sheet_function_utils import fill_series_list_to_max, fill_series_to_length
+from mitosheet.sheet_functions.sheet_function_utils import try_extend_series_to_index
 import pandas as pd
 import numpy as np
 import datetime
@@ -56,7 +56,7 @@ def FILLNAN(series: pd.Series, replacement: pd.Series) -> pd.Series:
     }
     """
     # Make sure the replacement series is long enough
-    replacement = fill_series_to_length(replacement, len(series))
+    replacement = try_extend_series_to_index(replacement, series.index)
 
     return series.fillna(replacement)
 
@@ -93,14 +93,17 @@ def OFFSET(series: pd.Series, offset) -> pd.Series:
     length = len(series)
     # If the shift is too big, we just return an empty series
     if abs(offset) >= length:
-        return pd.Series([np.NaN] * length)
+        return pd.Series([np.NaN] * length, index=series.index)
     
     if offset < 0:
-        # Otherwise, append the NaNs to the front, and chop at the correct length
-        return pd.concat([pd.Series([np.NaN] * (offset * -1)), series], ignore_index=True).head(length)
+        return pd.Series(
+            [np.NaN] * (offset * -1) + series.tolist()
+        ).head(length).reindex(series.index)
     else:
         remaining_series = series.tail(length - offset)
-        return pd.concat([remaining_series, pd.Series([np.NaN] * offset)], ignore_index=True).head(length)
+        return pd.Series(
+            remaining_series.tolist() + [np.NaN] * offset,
+        ).head(length).reindex(series.index)
 
 
 @handle_sheet_function_errors
