@@ -18,7 +18,7 @@ import pandas as pd
 import numpy as np
 
 from mitosheet.sheet_functions.types.decorators import convert_arg_to_series_type, convert_args_to_series_type, filter_nans, cast_output, handle_sheet_function_errors
-from mitosheet.sheet_functions.sheet_function_utils import fill_series_list_to_max, fill_series_to_length
+from mitosheet.sheet_functions.sheet_function_utils import fill_series_with_one_index, try_extend_series_to_index
 
 
 @handle_sheet_function_errors
@@ -77,7 +77,7 @@ def CONCAT(*argv) -> pd.Series:
     """
 
     # We make sure all the series are the max length, so the concat has something at every index
-    argv = fill_series_list_to_max(argv)
+    argv = fill_series_with_one_index(argv)
 
     return functools.reduce((lambda x, y: x + y), argv)
 
@@ -96,7 +96,6 @@ def CONCAT(*argv) -> pd.Series:
     'error',
     'error'
 )
-@filter_nans
 def FIND(series, substrings) -> pd.Series:
     """
     {
@@ -120,10 +119,13 @@ def FIND(series, substrings) -> pd.Series:
     """
 
     # If there aren't enough substrings, we fill it to the end
-    substrings = fill_series_to_length(substrings, series.size)
+    substrings = try_extend_series_to_index(substrings, series.index)
 
     # Then, we find each substring
-    return pd.Series(data=[string.find(substring) + 1 for string, substring in zip(series, substrings)])
+    return pd.Series(
+        [string.find(substring) + 1 for string, substring in zip(series, substrings)], 
+        index=series.index
+    )
 
 
 @handle_sheet_function_errors
@@ -167,9 +169,12 @@ def LEFT(series, num_chars=None) -> pd.Series:
         num_chars = pd.Series(data=[1] * series.size)
 
     # If there aren't enough char splits, we fill it to the end
-    num_chars = fill_series_to_length(num_chars, series.size)
+    num_chars = try_extend_series_to_index(num_chars, series.index)
     # And then slice the string on the left
-    return pd.Series(data=[string[:int(num_char)] for string, num_char in zip(series, num_chars)])
+    return pd.Series(
+        [string[:int(num_char)] for string, num_char in zip(series, num_chars)],
+        index=series.index
+    )
 
 
 @handle_sheet_function_errors
@@ -277,13 +282,16 @@ def MID(series, start_loc, num_chars) -> pd.Series:
     }
     """
     # If there aren't enough char splits, we fill it to the end
-    start_loc = fill_series_to_length(start_loc, series.size)
-    num_chars = fill_series_to_length(num_chars, series.size)
+    start_loc = try_extend_series_to_index(start_loc, series.index)
+    num_chars = try_extend_series_to_index(num_chars, series.index)
     # And then slice the string on the left
-    return pd.Series(data=[
-        string[start - 1: start - 1 + int(num_char)] for string, start, num_char 
-        in zip(series, start_loc, num_chars)
-    ]) 
+    return pd.Series(
+        [
+            string[start - 1: start - 1 + int(num_char)] for string, start, num_char 
+            in zip(series, start_loc, num_chars)
+        ],
+        index=series.index
+    ) 
 
 
 @handle_sheet_function_errors
@@ -356,9 +364,12 @@ def RIGHT(series, num_chars=None) -> pd.Series:
         num_chars = pd.Series(data=[1] * series.size)
 
     # If there aren't enough char splits, we fill it to the end
-    num_chars = fill_series_to_length(num_chars, series.size)
+    num_chars = try_extend_series_to_index(num_chars, series.index)
     # And then slice the string on the left
-    return pd.Series(data=[string[-int(num_char):] if num_char > 0 else '' for string, num_char in zip(series, num_chars)])
+    return pd.Series(
+        [string[-int(num_char):] if num_char > 0 else '' for string, num_char in zip(series, num_chars)],
+        index=series.index
+    )
 
 
 @handle_sheet_function_errors
@@ -418,13 +429,14 @@ def SUBSTITUTE(series, old_text, new_text, count=None):
         ]
     }
     """
-    old_text = fill_series_to_length(old_text, series.size)
-    new_text = fill_series_to_length(new_text, series.size)
+    old_text = try_extend_series_to_index(old_text, series.index)
+    new_text = try_extend_series_to_index(new_text, series.index)
     if count is None:
-        count = fill_series_to_length(pd.Series(data=[-1]), series.size)
+        count = try_extend_series_to_index(pd.Series(data=[-1]), series.index)
 
     return pd.Series(
-        [string.replace(old, new, c) for string, old, new, c in zip(series, old_text, new_text, count)]
+        [string.replace(old, new, c) for string, old, new, c in zip(series, old_text, new_text, count)],
+        index=series.index
     )
 
 @handle_sheet_function_errors
