@@ -22,9 +22,6 @@ def to_boolean_series(
     """
     Converts the given object to a boolean series. Note that on_uncastable_arg_element
     is irrelevant here, as anything can be turned into a boolean. 
-
-    TODO: improve the string cast, it's dumb currently. It should detect true and True
-    and false and False, and otherwise default to something reasonable?
     """
     from_type = get_mito_type(unknown_object)
 
@@ -39,8 +36,34 @@ def to_boolean_series(
         # For now, we treat all dates as true, and NaN values as False
         return ~unknown_object.isna()
     elif from_type == NUMBER_SERIES:
-        return unknown_object.astype('bool')
+        return unknown_object.fillna(False).astype('bool')
     elif from_type == STRING_SERIES:
-        return unknown_object.astype('bool')
+        string_to_bool_conversion_dict = {
+            '1': True,
+            '1.0': True,
+            1: True,
+            1.0: True,
+            'TRUE': True,
+            'True': True, 
+            'true': True,
+            'T': True,
+            't': True,
+            'Y': True,
+            'y': True,
+            #########################
+            '0': False,
+            '0.0': False,
+            0: False,
+            0.0: False,
+            'FALSE': False,
+            'False': False,
+            'false': False,
+            'F': False,
+            'f': False,
+            'N': False,
+            'n': False
+        }
+        # Convert any NaN values to False
+        return unknown_object.map(string_to_bool_conversion_dict).fillna(False)
     else:
         return None
\ No newline at end of file
