@@ -5,20 +5,29 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import copy
-from mitosheet.state import State
 from typing import Any, Dict, List, Optional
-from mitosheet.step_performers.step_performer import StepPerformer
-from mitosheet.mito_analytics import log
-from mitosheet.errors import make_invalid_column_type_change_error
-from mitosheet.sheet_functions.types.to_number_series import to_number_series
-from mitosheet.sheet_functions.types.to_boolean_series import to_boolean_series
-from mitosheet.sheet_functions.types.utils import (
-    get_datetime_format, get_mito_type, is_bool_dtype, is_float_dtype, is_int_dtype,
-    is_string_dtype, is_datetime_dtype, is_timedelta_dtype
-) 
-import pandas as pd
 
- 
+import pandas as pd
+from mitosheet.errors import get_recent_traceback, make_invalid_column_type_change_error
+from mitosheet.mito_analytics import log
+from mitosheet.sheet_functions.types.to_boolean_series import to_boolean_series
+from mitosheet.sheet_functions.types.to_number_series import to_number_series
+from mitosheet.sheet_functions.types.to_timedelta_series import \
+    to_timedelta_series
+from mitosheet.sheet_functions.types.utils import (get_datetime_format,
+                                                   get_mito_type,
+                                                   is_bool_dtype,
+                                                   is_datetime_dtype,
+                                                   is_float_dtype,
+                                                   is_int_dtype,
+                                                   is_string_dtype,
+                                                   is_timedelta_dtype)
+from mitosheet.state import State
+from mitosheet.step_performers.column_steps.set_column_formula import (
+    refresh_dependant_columns, transpile_dependant_columns)
+from mitosheet.step_performers.step_performer import StepPerformer
+
+
 class ChangeColumnDtypeStepPerformer(StepPerformer):
     """"
     A step that allows changing the dtype of a column to a different
@@ -29,7 +38,7 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
 
     @classmethod
     def step_version(cls) -> int:
-        return 1
+        return 2
 
     @classmethod
     def step_type(cls) -> str:
@@ -45,7 +54,10 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
 
     @classmethod
     def saturate(cls, prev_state: State, params) -> Dict[str, str]:
-        params['old_dtype'] = str(prev_state.dfs[params['sheet_index']][params['column_header']].dtype)
+        sheet_index = params['sheet_index']
+        column_id = params['column_id']
+        column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
+        params['old_dtype'] = str(prev_state.dfs[sheet_index][column_header].dtype)
         return params
 
     @classmethod
@@ -53,13 +65,15 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
         cls,
         prev_state: State,
         sheet_index: int,
-        column_header: str,
+        column_id: str,
         old_dtype: str,
         new_dtype: str,
         **params
     ) -> State:
         # Create the post state
         post_state = copy(prev_state)
+
+        column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
         
         column: pd.Series = prev_state.dfs[sheet_index][column_header]
         new_column = column
@@ -89,7 +103,7 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
                     )
             if is_int_dtype(old_dtype):
                 if is_bool_dtype(new_dtype):
-                    new_column = column.astype('bool')
+                    new_column = column.fillna(False).astype('bool')
                 elif is_int_dtype(new_dtype):
                     pass
                 elif is_float_dtype(new_dtype):
@@ -103,14 +117,10 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
                         errors='coerce'
                     )
                 elif is_timedelta_dtype(new_dtype):
-                    new_column = pd.to_timedelta(
-                        column, 
-                        unit='s',
-                        errors='coerce'
-                    )
+                    new_column = to_timedelta_series(column)
             elif is_float_dtype(old_dtype):
                 if is_bool_dtype(new_dtype):
-                    new_column = column.astype('bool')
+                    new_column = column.fillna(False).astype('bool')
                 elif is_int_dtype(new_dtype):
                     new_column = column.astype('int')
                 elif is_float_dtype(new_dtype):
@@ -124,11 +134,7 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
                         errors='coerce'
                     )
                 elif is_timedelta_dtype(new_dtype):
-                    new_column = pd.to_timedelta(
-                        column, 
-                        unit='s',
-                        errors='coerce'
-                    )
+                    new_column = to_timedelta_series(column)
             elif is_string_dtype(old_dtype):
                 if is_bool_dtype(new_dtype):
                     new_column = to_boolean_series(new_column)
@@ -155,10 +161,7 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
                             errors='coerce'
                         )
                 elif is_timedelta_dtype(new_dtype):
-                    new_column = pd.to_timedelta(
-                        column,
-                        errors='coerce'
-                    )
+                    new_column = to_timedelta_series(column)
             elif is_datetime_dtype(old_dtype):
                 if is_bool_dtype(new_dtype):
                     new_column = ~column.isnull()
@@ -198,11 +201,11 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
 
             # We update the column, as well as the type of the column
             post_state.dfs[sheet_index][column_header] = new_column
-            post_state.column_type[sheet_index][column_header] = get_mito_type(new_column)
+            post_state.column_type[sheet_index][column_id] = get_mito_type(new_column)
             
             # We check if there are formula columns that rely on this type, and log if
             # so, so that know if this is an issue folks run into
-            if len(post_state.column_evaluation_graph[sheet_index][column_header]) > 0:
+            if len(post_state.column_evaluation_graph[sheet_index][column_id]) > 0:
                 log(
                     'change_column_dtype_column_has_dependents',
                     {
@@ -210,8 +213,11 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
                     }
                 )
 
+            refresh_dependant_columns(post_state, post_state.dfs[sheet_index], sheet_index)
+
             return post_state, None
         except:
+            print(get_recent_traceback())
             raise make_invalid_column_type_change_error(
                 column_header,
                 old_dtype,
@@ -226,11 +232,12 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
         post_state: State,
         execution_data: Optional[Dict[str, Any]],
         sheet_index: int,
-        column_header: str,
+        column_id: str,
         old_dtype: str,
         new_dtype: str
     ) -> List[str]:
         df_name = post_state.df_names[sheet_index]
+        column_header = post_state.column_ids.get_column_header_by_id(sheet_index, column_id)
         column = prev_state.dfs[sheet_index][column_header]
 
         conversion_code = f'{df_name}[\'{column_header}\']'
@@ -257,7 +264,7 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
                 )
         elif is_int_dtype(old_dtype):
             if is_bool_dtype(new_dtype):
-                conversion_code = f'{df_name}[\'{column_header}\'].astype(\'bool\')'
+                conversion_code = f'{df_name}[\'{column_header}\'].fillna(False).astype(\'bool\')'
             elif is_int_dtype(new_dtype):
                 pass
             elif is_float_dtype(new_dtype):
@@ -270,7 +277,7 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
                 conversion_code = f'pd.to_timedelta({df_name}[\'{column_header}\'], unit=\'s\', errors=\'coerce\')'
         elif is_float_dtype(old_dtype):
             if is_bool_dtype(new_dtype):
-                conversion_code = f'{df_name}[\'{column_header}\'].astype(\'bool\')'
+                conversion_code = f'{df_name}[\'{column_header}\'].fillna(False).astype(\'bool\')'
             elif is_int_dtype(new_dtype):
                 conversion_code = f'{df_name}[\'{column_header}\'].astype(\'int\')'
             elif is_float_dtype(new_dtype):
@@ -334,16 +341,19 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
             elif is_timedelta_dtype(new_dtype):
                 pass
 
-        return [f'{df_name}[\'{column_header}\'] = {conversion_code}']
+        code = [f'{df_name}[\'{column_header}\'] = {conversion_code}']
+        code = code + transpile_dependant_columns(post_state, sheet_index, column_header)
+
+        return code
 
     @classmethod
     def describe(
         cls,
         sheet_index: int,
-        column_header: str,
+        column_id: str,
         old_dtype: str,
         new_dtype: str,
         df_names=None,
         **params
     ) -> str:
-        return f'Changed {column_header} from {old_dtype} to {new_dtype}'
\ No newline at end of file
+        return f'Changed {column_id} from {old_dtype} to {new_dtype}'
