@@ -272,6 +272,9 @@ def get_details_from_operator_type_error(error):
     If you write pd.Series(['true']) ^ 10
     - Cannot perform 'xor' with a dtyped [object] array and scalar of type [bool]
 
+    On Python 3.6, there is one error when you try and append a number to 
+    a string, where it says `must be str, not int`.
+
     ^ NOTE: the above two errors makes pretty much no sense at all, but it appears
     to be casting the number to a boolean? So we choose to handle this as a number,
     as this is when you would be 
@@ -301,7 +304,9 @@ def get_details_from_operator_type_error(error):
         # casting that goes on in the error message that makes it hard to tell. As such,
         # we report the most likely error.
         return ('^', 'number', 'str')
-
+    if error_message.startswith('must be str, not'):
+        # When adding a number to a string
+        return ('+', 'str', 'number')
 
     return None
 
