@@ -67,12 +67,14 @@ NUMBER_FILTER_CONDITIONS = [
 ]
 
 FC_DATETIME_EXACTLY = 'datetime_exactly'
+FC_DATETIME_NOT_EXACTLY = 'datetime_not_exactly'
 FC_DATETIME_GREATER = 'datetime_greater'
 FC_DATETIME_GREATER_THAN_OR_EQUAL = 'datetime_greater_than_or_equal'
 FC_DATETIME_LESS = 'datetime_less'
 FC_DATETIME_LESS_THAN_OR_EQUAL = 'datetime_less_than_or_equal'
 DATETIME_FILTER_CONDITIONS = [
     FC_DATETIME_EXACTLY,
+    FC_DATETIME_NOT_EXACTLY,
     FC_DATETIME_GREATER,
     FC_DATETIME_GREATER_THAN_OR_EQUAL,
     FC_DATETIME_LESS,
@@ -86,7 +88,7 @@ class FilterStepPerformer(StepPerformer):
 
     @classmethod
     def step_version(cls) -> int:
-        return 2
+        return 3
 
     @classmethod
     def step_type(cls) -> str:
@@ -124,19 +126,14 @@ class FilterStepPerformer(StepPerformer):
         cls,
         prev_state: State,
         sheet_index: int,
-        column_header: str,
+        column_id: str,
         operator: str,
         filters,
         **params
     ) -> State:
-        # if the sheet doesn't exist, throw an error
-        if not prev_state.does_sheet_index_exist_within_state(sheet_index):
-            raise make_no_sheet_error(sheet_index)
 
-        # We check that the filtered column exists 
-        missing_column = set([column_header]).difference(prev_state.column_metatype[sheet_index].keys())
-        if len(missing_column) > 0: 
-            raise make_no_column_error(missing_column)
+        # Get the correct column_header
+        column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
 
         # If no errors we create a new step for this filter
         post_state = deepcopy(prev_state)
@@ -150,8 +147,8 @@ class FilterStepPerformer(StepPerformer):
         )
 
         # keep track of which columns are filtered
-        post_state.column_filters[sheet_index][column_header]['operator'] = operator
-        post_state.column_filters[sheet_index][column_header]['filters'] = filters
+        post_state.column_filters[sheet_index][column_id]['operator'] = operator
+        post_state.column_filters[sheet_index][column_id]['filters'] = filters
 
         return post_state, None
 
@@ -162,13 +159,15 @@ class FilterStepPerformer(StepPerformer):
         post_state: State,
         execution_data: Optional[Dict[str, Any]],
         sheet_index: int,
-        column_header: str,
+        column_id: str,
         operator: str,
         filters,
         **params
     ) -> List[str]:
         df_name = post_state.df_names[sheet_index]
 
+        column_header = post_state.column_ids.get_column_header_by_id(sheet_index, column_id)
+
         filter_strings = []
         for filter_or_group in filters:
             # If it is a group, we build the code for each filter, and then combine them at the end
@@ -193,20 +192,18 @@ class FilterStepPerformer(StepPerformer):
         elif len(filter_strings) == 1:
             return [
                 f'{df_name} = {df_name}[{filter_strings[0]}]',
-                f'{df_name} = {df_name}.reset_index(drop=True)'
             ]
         else:
             filter_string = combine_filter_strings(operator, filter_strings, split_lines=True)
             return [
                 f'{df_name} = {df_name}[{filter_string}]',
-                f'{df_name} = {df_name}.reset_index(drop=True)'
             ]
 
     @classmethod
     def describe(
         cls,
         sheet_index: int,
-        column_header: str,
+        column_id: str,
         operator: str,
         filters,
         df_names=None,
@@ -214,8 +211,8 @@ class FilterStepPerformer(StepPerformer):
     ) -> str:
         if df_names is not None:
             df_name = df_names[sheet_index]
-            return f'Filtered {column_header} in {df_name}'
-        return f'Filtered {column_header}'
+            return f'Filtered {column_id} in {df_name}'
+        return f'Filtered {column_id}'
 
 
 def get_applied_filter(df, column_header, filter_):
@@ -295,6 +292,8 @@ def get_applied_filter(df, column_header, filter_):
 
         if condition == FC_DATETIME_EXACTLY:
             return df[column_header] == timestamp
+        elif condition == FC_DATETIME_NOT_EXACTLY:
+            return df[column_header] != timestamp
         elif condition == FC_DATETIME_GREATER:
             return df[column_header] > timestamp
         elif condition == FC_DATETIME_GREATER_THAN_OR_EQUAL:
@@ -354,7 +353,7 @@ def _execute_filter(
             applied_filters.append(get_applied_filter(df, column_header, filter_or_group))    
     
     if len(applied_filters) > 0:
-        return df[combine_filters(operator, applied_filters)].reset_index(drop=True)
+        return df[combine_filters(operator, applied_filters)]
     else:
         return df
 
@@ -392,6 +391,7 @@ def get_filter_string(df_name, column_header, filter_):
 
         # DATES
         FC_DATETIME_EXACTLY: '{df_name}[\'{column_header}\'] == pd.to_datetime(\'{value}\')',
+        FC_DATETIME_NOT_EXACTLY: '{df_name}[\'{column_header}\'] != pd.to_datetime(\'{value}\')',
         FC_DATETIME_GREATER: '{df_name}[\'{column_header}\'] > pd.to_datetime(\'{value}\')',
         FC_DATETIME_GREATER_THAN_OR_EQUAL: '{df_name}[\'{column_header}\'] >= pd.to_datetime(\'{value}\')',
         FC_DATETIME_LESS: '{df_name}[\'{column_header}\'] < pd.to_datetime(\'{value}\')',
