@@ -25,7 +25,7 @@ class SortStepPerformer(StepPerformer):
 
     @classmethod
     def step_version(cls) -> int:
-        return 1
+        return 2
 
     @classmethod
     def step_type(cls) -> str:
@@ -48,31 +48,23 @@ class SortStepPerformer(StepPerformer):
         cls,
         prev_state: State,
         sheet_index: int,
-        column_header: str,
+        column_id: str,
         sort_direction: str,
         **params
     ):
         """
         Returns the new new post state after sorting the sheet
-        at `sheet_index` by the passed `column_header` in the given
+        at `sheet_index` by the passed `column_id` in the given
         `sort_direction`
         """
 
-        # if the sheet doesn't exist, throw an error
-        if not prev_state.does_sheet_index_exist_within_state(sheet_index):
-            raise make_no_sheet_error(sheet_index)
-
-        # We check that the sorted column exists 
-        missing_column = set([column_header]).difference(prev_state.column_metatype[sheet_index].keys())
-        if len(missing_column) > 0: 
-            raise make_no_column_error(missing_column)
+        column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
 
         # We make a new state to modify it
         post_state = deepcopy(prev_state)
 
         try: 
-            new_df = prev_state.dfs[sheet_index].sort_values(by=column_header, ascending=(sort_direction == ASCENDING), na_position='first')
-            new_df = new_df.reset_index(drop=True)
+            new_df = prev_state.dfs[sheet_index].sort_values(by=column_header, ascending=(sort_direction == ASCENDING), na_position=('first' if sort_direction == ASCENDING else 'last'))
             post_state.dfs[sheet_index] = new_df
         except TypeError as e:
             # A NameError occurs when you try to sort a column with incomparable 
@@ -90,25 +82,27 @@ class SortStepPerformer(StepPerformer):
         post_state: State,
         execution_data: Optional[Dict[str, Any]],
         sheet_index: int,
-        column_header: str,
+        column_id: str,
         sort_direction: str
     ) -> List[str]:
         df_name = post_state.df_names[sheet_index]
+        column_header = post_state.column_ids.get_column_header_by_id(sheet_index, column_id)
+        
+        na_position_string = 'first' if sort_direction == ASCENDING else 'last'
         return [
-            f'{df_name} = {df_name}.sort_values(by=\'{column_header}\', ascending={sort_direction == ASCENDING}, na_position=\'first\')', 
-            f'{df_name} = {df_name}.reset_index(drop=True)'
+            f'{df_name} = {df_name}.sort_values(by=\'{column_header}\', ascending={sort_direction == ASCENDING}, na_position=\'{na_position_string}\')', 
         ]
 
     @classmethod
     def describe(
         cls,
         sheet_index: int,
-        column_header: str,
+        column_id: str,
         sort_direction: str,
         df_names=None,
         **params
     ) -> str:
         if df_names is not None:
             df_name = df_names[sheet_index]
-            return f'Sorted {column_header} in {df_name} in {sort_direction} order'
-        return f'Sorted {column_header} in {sort_direction} order'
\ No newline at end of file
+            return f'Sorted {column_id} in {df_name} in {sort_direction} order'
+        return f'Sorted {column_id} in {sort_direction} order'
\ No newline at end of file
